
/* 
 * Copyright (c) 1993-2003,2012 LAAS/CNRS
 * All rights reserved.
 *
 * Redistribution and use  in source  and binary  forms,  with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *   1. Redistributions of  source  code must retain the  above copyright
 *      notice, this list of conditions and the following disclaimer.
 *   2. Redistributions in binary form must reproduce the above copyright
 *      notice,  this list of  conditions and the following disclaimer in
 *      the  documentation  and/or  other   materials provided  with  the
 *      distribution.
 *
 * THIS  SOFTWARE IS PROVIDED BY  THE  COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND  ANY  EXPRESS OR IMPLIED  WARRANTIES,  INCLUDING,  BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES  OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR  PURPOSE ARE DISCLAIMED. IN  NO EVENT SHALL THE COPYRIGHT
 * HOLDERS OR      CONTRIBUTORS  BE LIABLE FOR   ANY    DIRECT, INDIRECT,
 * INCIDENTAL,  SPECIAL,  EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF  SUBSTITUTE GOODS OR SERVICES; LOSS
 * OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN  CONTRACT, STRICT LIABILITY, OR
 * TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
 * USE   OF THIS SOFTWARE, EVEN   IF ADVISED OF   THE POSSIBILITY OF SUCH
 * DAMAGE.
 */

/*------------------  Fichier gnr automatiquement ------------------*/
/*------------------  Ne pas diter manuellement !!! ------------------*/

#ifndef platine_MSG_LIB_H
#define platine_MSG_LIB_H

#include "portLib.h"
#include "csLib.h"
#include "posterLib.h"
 
#include "platineType.h"

#define TIME_WAIT_REPLY           /*2000*/ 0
 



/*----------- Tailles des messages et boites aux lettres  ----------*/

/* Taille du buffer utilise dans la bal pour un mesage de taille size
 * (cf servMbox pour UNIX et h2rgnLib pour VXWORKS )
 */


#define BUF_SIZE(size) \
   (size + 4 - (size & 3) + sizeof(LETTER_HDR) + 8)

/**
 ** Boite aux lettres reception requetes 
 **/
#define  PLATINE_MBOX_NAME                  genomInstanceName("platine")

#define  PLATINE_MAX_RQST_SIZE              88

#define  PLATINE_MBOX_RQST_SIZE       \
 (BUF_SIZE(PLATINE_MAX_RQST_SIZE) * SERV_NMAX_RQST_ID)

/** 
 ** Taille max repliques (serveur)
 **/
#define  PLATINE_MAX_INTERMED_REPLY_SIZE   (sizeof(int))

#define  PLATINE_MAX_REPLY_SIZE             176

/** 
 ** Taille bal clients pour reception repliques 
 **/
#define  PLATINE_CLIENT_MBOX_REPLY_SIZE   \
((BUF_SIZE(PLATINE_MAX_REPLY_SIZE) \
   + BUF_SIZE(PLATINE_MAX_INTERMED_REPLY_SIZE)) \
 * CLIENT_NMAX_RQST_ID)

/*-------------------------- Liste des requetes  -------------------------*/

#define PLATINE_INITDRIVER_RQST 0
#define PLATINE_GETSERIALPARAMS_RQST 1
#define PLATINE_RESET_RQST 2
#define PLATINE_GETPLATINEPARAMS_RQST 3
#define PLATINE_SETSPEED_RQST 4
#define PLATINE_SETSPEEDPROFILE_RQST 5
#define PLATINE_SETPOWERMODES_RQST 6
#define PLATINE_SETUPDATEPOSTERPERIOD_RQST 7
#define PLATINE_STOP_RQST 8
#define PLATINE_SETOFFSET_RQST 9
#define PLATINE_CMDPOSPAN_RQST 10
#define PLATINE_CMDPOSTILT_RQST 11
#define PLATINE_CMDPOSCOORD_RQST 12
#define PLATINE_TRACKPOS_RQST 13
#define PLATINE_TRACKSPEED_RQST 14
#define PLATINE_SETPLATINEPOSONROBOT_RQST 15
#define PLATINE_GETPLATINEPOSONROBOT_RQST 16
#define PLATINE_AIMATTARGETPOINT_RQST 17
#define PLATINE_TRACKTARGETPOINT_RQST 18
#define PLATINE_GETCONSTCONVERT_RQST 19
#define PLATINE_SETDEFAULTPTSETTINGS_RQST 20
#define PLATINE_SENDASCIICMD_RQST 21
#define PLATINE_RESETPTUDRIVER_RQST 22
#define PLATINE_GETUPDATEPOSTERPERIOD_RQST 23
#define PLATINE_GETOFFSET_RQST 24
#define PLATINE_VERBOSESWITCH_RQST 25
#define PLATINE_ABORT_RQST 26


/*---------------- PROTOTYPES DES FONCTIONS EXTERNES ------------------*/

#ifdef __cplusplus
extern "C" {
#endif

STATUS platineClientInit (CLIENT_ID *pClientId);

STATUS platineClientEnd (CLIENT_ID clientId);

int platineAbortRqstSend (CLIENT_ID clientId, 
			   int *pRqstId,
			   int *activity,
			   int replyTimeOut);

int platineAbortReplyRcv (CLIENT_ID clientId, 
			   int rqstId, 
			   int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			   int *bilan);

int platineAbortRqstAndRcv (CLIENT_ID clientId, 
			     int *activity,
			     int *bilan);




extern STATUS platineInitDriverRqstSend (CLIENT_ID clientId, int *pRqstId,
					 PLATINE_DRIVER_PARAMS *(in_driverParams),
					 int replyTimeOut);

extern int platineInitDriverReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int platineInitDriverRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					PLATINE_DRIVER_PARAMS *(in_driverParams), 
					
					int *activity, int *bilan);

extern int platineInitDriverRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					PLATINE_DRIVER_PARAMS *(in_driverParams), 
					
					int *activity,
					int *bilan);




extern STATUS platineGetSerialParamsRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 
					 int replyTimeOut);

int platineGetSerialParamsReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       PLATINE_DRIVER_PARAMS *(out_driverParams),
			       int *bilan);

int platineGetSerialParamsRqstAndRcv (CLIENT_ID clientId, 
				  
				 PLATINE_DRIVER_PARAMS *(out_driverParams),
				 int *bilan);




extern STATUS platineResetRqstSend (CLIENT_ID clientId, int *pRqstId,
					 
					 int replyTimeOut);

extern int platineResetReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int platineResetRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					 
					
					int *activity, int *bilan);

extern int platineResetRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					 
					
					int *activity,
					int *bilan);




extern STATUS platineGetPlatineParamsRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 PLATINE_UNITY *(in_unity),
					 int replyTimeOut);

int platineGetPlatineParamsReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       PLATINE_PARAMS_STR *(out_platineParamsRq),
			       int *bilan);

int platineGetPlatineParamsRqstAndRcv (CLIENT_ID clientId, 
				 PLATINE_UNITY *(in_unity), 
				 PLATINE_PARAMS_STR *(out_platineParamsRq),
				 int *bilan);




extern STATUS platineSetSpeedRqstSend (CLIENT_ID clientId, int *pRqstId,
					 PLATINE_SET_PARAM *(in_setParam),
					 int replyTimeOut);

extern int platineSetSpeedReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int platineSetSpeedRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					PLATINE_SET_PARAM *(in_setParam), 
					
					int *activity, int *bilan);

extern int platineSetSpeedRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					PLATINE_SET_PARAM *(in_setParam), 
					
					int *activity,
					int *bilan);




extern STATUS platineSetSpeedProfileRqstSend (CLIENT_ID clientId, int *pRqstId,
					 PLATINE_AXIS_SET_SPEED_PROFILE *(in_setSpeedProfile),
					 int replyTimeOut);

extern int platineSetSpeedProfileReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int platineSetSpeedProfileRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					PLATINE_AXIS_SET_SPEED_PROFILE *(in_setSpeedProfile), 
					
					int *activity, int *bilan);

extern int platineSetSpeedProfileRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					PLATINE_AXIS_SET_SPEED_PROFILE *(in_setSpeedProfile), 
					
					int *activity,
					int *bilan);




extern STATUS platineSetPowerModesRqstSend (CLIENT_ID clientId, int *pRqstId,
					 PLATINE_POWER_PARAMS *(in_power),
					 int replyTimeOut);

extern int platineSetPowerModesReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int platineSetPowerModesRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					PLATINE_POWER_PARAMS *(in_power), 
					
					int *activity, int *bilan);

extern int platineSetPowerModesRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					PLATINE_POWER_PARAMS *(in_power), 
					
					int *activity,
					int *bilan);




extern STATUS platineSetUpdatePosterPeriodRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 int *(in_updatePosterPeriod),
					 int replyTimeOut);

int platineSetUpdatePosterPeriodReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       
			       int *bilan);

int platineSetUpdatePosterPeriodRqstAndRcv (CLIENT_ID clientId, 
				 int *(in_updatePosterPeriod), 
				 
				 int *bilan);




extern STATUS platineStopRqstSend (CLIENT_ID clientId, int *pRqstId,
					 
					 int replyTimeOut);

extern int platineStopReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int platineStopRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					 
					
					int *activity, int *bilan);

extern int platineStopRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					 
					
					int *activity,
					int *bilan);




extern STATUS platineSetOffsetRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 PLATINE_SET_PARAM *(in_setParam),
					 int replyTimeOut);

int platineSetOffsetReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       
			       int *bilan);

int platineSetOffsetRqstAndRcv (CLIENT_ID clientId, 
				 PLATINE_SET_PARAM *(in_setParam), 
				 
				 int *bilan);




extern STATUS platineCmdPosPanRqstSend (CLIENT_ID clientId, int *pRqstId,
					 PLATINE_REF_AXIS_POS_STR *(in_pan),
					 int replyTimeOut);

extern int platineCmdPosPanReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int platineCmdPosPanRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					PLATINE_REF_AXIS_POS_STR *(in_pan), 
					
					int *activity, int *bilan);

extern int platineCmdPosPanRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					PLATINE_REF_AXIS_POS_STR *(in_pan), 
					
					int *activity,
					int *bilan);




extern STATUS platineCmdPosTiltRqstSend (CLIENT_ID clientId, int *pRqstId,
					 PLATINE_REF_AXIS_POS_STR *(in_tilt),
					 int replyTimeOut);

extern int platineCmdPosTiltReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int platineCmdPosTiltRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					PLATINE_REF_AXIS_POS_STR *(in_tilt), 
					
					int *activity, int *bilan);

extern int platineCmdPosTiltRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					PLATINE_REF_AXIS_POS_STR *(in_tilt), 
					
					int *activity,
					int *bilan);




extern STATUS platineCmdPosCoordRqstSend (CLIENT_ID clientId, int *pRqstId,
					 PLATINE_REF_COORD_POS_STR *(in_coord),
					 int replyTimeOut);

extern int platineCmdPosCoordReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int platineCmdPosCoordRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					PLATINE_REF_COORD_POS_STR *(in_coord), 
					
					int *activity, int *bilan);

extern int platineCmdPosCoordRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					PLATINE_REF_COORD_POS_STR *(in_coord), 
					
					int *activity,
					int *bilan);




extern STATUS platineTrackPosRqstSend (CLIENT_ID clientId, int *pRqstId,
					 GEN_STRING64 *(in_posterName),
					 int replyTimeOut);

extern int platineTrackPosReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int platineTrackPosRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					GEN_STRING64 *(in_posterName), 
					
					int *activity, int *bilan);

extern int platineTrackPosRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					GEN_STRING64 *(in_posterName), 
					
					int *activity,
					int *bilan);




extern STATUS platineTrackSpeedRqstSend (CLIENT_ID clientId, int *pRqstId,
					 GEN_STRING64 *(in_posterName),
					 int replyTimeOut);

extern int platineTrackSpeedReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int platineTrackSpeedRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					GEN_STRING64 *(in_posterName), 
					
					int *activity, int *bilan);

extern int platineTrackSpeedRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					GEN_STRING64 *(in_posterName), 
					
					int *activity,
					int *bilan);




extern STATUS platineSetPlatinePosOnRobotRqstSend (CLIENT_ID clientId, int *pRqstId,
					 PLATINE_POS_RQST *(in_platineOriginPosOnRobotRqst),
					 int replyTimeOut);

extern int platineSetPlatinePosOnRobotReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int platineSetPlatinePosOnRobotRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					PLATINE_POS_RQST *(in_platineOriginPosOnRobotRqst), 
					
					int *activity, int *bilan);

extern int platineSetPlatinePosOnRobotRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					PLATINE_POS_RQST *(in_platineOriginPosOnRobotRqst), 
					
					int *activity,
					int *bilan);




extern STATUS platineGetPlatinePosOnRobotRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 
					 int replyTimeOut);

int platineGetPlatinePosOnRobotReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       PLATINE_POS_RQST *(out_platineOriginPosOnRobotRqst),
			       int *bilan);

int platineGetPlatinePosOnRobotRqstAndRcv (CLIENT_ID clientId, 
				  
				 PLATINE_POS_RQST *(out_platineOriginPosOnRobotRqst),
				 int *bilan);




extern STATUS platineAimAtTargetPointRqstSend (CLIENT_ID clientId, int *pRqstId,
					 PLATINE_CARTESIAN_TARGET *(in_cartesianTarget),
					 int replyTimeOut);

extern int platineAimAtTargetPointReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int platineAimAtTargetPointRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					PLATINE_CARTESIAN_TARGET *(in_cartesianTarget), 
					
					int *activity, int *bilan);

extern int platineAimAtTargetPointRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					PLATINE_CARTESIAN_TARGET *(in_cartesianTarget), 
					
					int *activity,
					int *bilan);




extern STATUS platineTrackTargetPointRqstSend (CLIENT_ID clientId, int *pRqstId,
					 PLATINE_TRACK_TARGET *(in_trackTarget),
					 int replyTimeOut);

extern int platineTrackTargetPointReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int platineTrackTargetPointRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					PLATINE_TRACK_TARGET *(in_trackTarget), 
					
					int *activity, int *bilan);

extern int platineTrackTargetPointRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					PLATINE_TRACK_TARGET *(in_trackTarget), 
					
					int *activity,
					int *bilan);




extern STATUS platineGetConstConvertRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 
					 int replyTimeOut);

int platineGetConstConvertReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       PLATINE_CONVERT_PARAMS *(out_constConvert),
			       int *bilan);

int platineGetConstConvertRqstAndRcv (CLIENT_ID clientId, 
				  
				 PLATINE_CONVERT_PARAMS *(out_constConvert),
				 int *bilan);




extern STATUS platineSetDefaultPtSettingsRqstSend (CLIENT_ID clientId, int *pRqstId,
					 PLATINE_SET_SETTING *(in_settings),
					 int replyTimeOut);

extern int platineSetDefaultPtSettingsReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int platineSetDefaultPtSettingsRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					PLATINE_SET_SETTING *(in_settings), 
					
					int *activity, int *bilan);

extern int platineSetDefaultPtSettingsRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					PLATINE_SET_SETTING *(in_settings), 
					
					int *activity,
					int *bilan);




extern STATUS platineSendAsciiCmdRqstSend (CLIENT_ID clientId, int *pRqstId,
					 GEN_STRING64 *(in_asciiCmd),
					 int replyTimeOut);

extern int platineSendAsciiCmdReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int platineSendAsciiCmdRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					GEN_STRING64 *(in_asciiCmd), 
					
					int *activity, int *bilan);

extern int platineSendAsciiCmdRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					GEN_STRING64 *(in_asciiCmd), 
					
					int *activity,
					int *bilan);




extern STATUS platineResetPTUdriverRqstSend (CLIENT_ID clientId, int *pRqstId,
					 
					 int replyTimeOut);

extern int platineResetPTUdriverReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int platineResetPTUdriverRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					 
					
					int *activity, int *bilan);

extern int platineResetPTUdriverRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					 
					
					int *activity,
					int *bilan);




extern STATUS platineGetUpdatePosterPeriodRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 
					 int replyTimeOut);

int platineGetUpdatePosterPeriodReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       int *(out_updatePosterPeriod),
			       int *bilan);

int platineGetUpdatePosterPeriodRqstAndRcv (CLIENT_ID clientId, 
				  
				 int *(out_updatePosterPeriod),
				 int *bilan);




extern STATUS platineGetOffsetRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 
					 int replyTimeOut);

int platineGetOffsetReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       PLATINE_SET_PARAM *(out_setParam),
			       int *bilan);

int platineGetOffsetRqstAndRcv (CLIENT_ID clientId, 
				  
				 PLATINE_SET_PARAM *(out_setParam),
				 int *bilan);




extern STATUS platineVerboseSwitchRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 
					 int replyTimeOut);

int platineVerboseSwitchReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       
			       int *bilan);

int platineVerboseSwitchRqstAndRcv (CLIENT_ID clientId, 
				  
				 
				 int *bilan);


#ifdef __cplusplus
}
#endif
#endif /* platine_MSG_LIB_H */

